==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/pl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Successfully saved" : "Zapisywanie powiodło się",
    "Saving failed:" : "Zapisywanie nie powiodło się:",
    "is" : "jest",
    "is not" : "nie jest",
    "matches" : "pasuje",
    "does not match" : "nie pasuje",
    "Example: {placeholder}" : "Przykład: {placeholder}",
    "File size (upload)" : "Rozmiar pliku (wczytywanego)",
    "less" : "mniejszy",
    "less or equals" : "mniejszy lub równy",
    "greater or equals" : "większy lub równy",
    "greater" : "większy",
    "File system tag" : "Etykieta systemu plików",
    "is tagged with" : "jest oznaczony",
    "is not tagged with" : "Nie jest oznaczony",
    "Select tag…" : "Wybierz etykietę ...",
    "Request remote address" : "Uzyskaj zdalny adres",
    "matches IPv4" : "pasuje IPv4",
    "does not match IPv4" : "nie pasuje IPv4",
    "matches IPv6" : "pasuje IPv6",
    "does not match IPv6" : "nie pasuje IPv6",
    "Request time" : "Przekroczono czas odpowiedzi",
    "between" : "pomiędzy",
    "not between" : "nie pomiędzy",
    "Start" : "Start",
    "End" : "Koniec",
    "Select timezone…" : "Wybierz strefę czasową...",
    "Request URL" : "Żądanie URL",
    "Predefined URLs" : "Przedefiniowanie URLs",
    "Files WebDAV" : "Pliki WebDAV",
    "Sync clients" : "Klienci synchronizacji",
    "Android client" : "Klient Android",
    "iOS client" : "Klient iOS",
    "Desktop client" : "Klient na komputer",
    "is member of" : "Jest członkiem z",
    "is not member of" : "Nie jest członkiem z",
    "The given operator is invalid" : "Dana operacja jest nieprawidłowa",
    "The given file size is invalid" : "Podany rozmiar pliku jest nieprawidłowy",
    "The given tag id is invalid" : "Podane id etykiety jest nieprawidłowe",
    "The given IP range is invalid" : "Podany zakres adresów IP jest nieprawidłowy",
    "The given IP range is not valid for IPv4" : "Podany zakres adresów IP jest nieprawidłowy dla IPv4",
    "The given IP range is not valid for IPv6" : "Podany zakres adresów IP jest nieprawidłowy dla IPv6",
    "The given time span is invalid" : "Podany przedział czasowy jest nieprawidłowy",
    "The given start time is invalid" : "Podany czas rozpoczęcia jest nieprawidłowy",
    "The given end time is invalid" : "Podany czas zakończenia jest nieprawidłowy",
    "The given group does not exist" : "Podana grupa nie istnieje",
    "Check %s is invalid or does not exist" : "Sprawdź, czy %s jest nieprawidłowa lub nie istnieje",
    "Operation #%s does not exist" : "Operacja do wykonania #%s nie istnieje",
    "Operation %s does not exist" : "Operacja do wykonania %s nie istnieje",
    "Operation %s is invalid" : "Operacja %s jest nieprawidłowa",
    "Check %s does not exist" : "Sprawdź, czy %s nie istnieje",
    "Check %s is invalid" : "Sprawdź, czy %s jest nieprawidłowy",
    "Check #%s does not exist" : "Sprawdź, czy #%s nie istnieje",
    "Workflow" : "Wpływ na pracę",
    "Open documentation" : "Otwórz dokumentację",
    "Add rule group" : "Dodaj regułę grupy",
    "Short rule description" : "Krótki opis reguły",
    "Add rule" : "Dodaj regułę",
    "Reset" : "Reset",
    "Save" : "Zapisz",
    "Saving…" : "Zapisywanie...",
    "Loading…" : "Wczytywanie..."
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/pl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Saved" : "Zapisano",
    "Saving failed:" : "Zapis się nie udał:",
    "File MIME type" : "Typy plików MIME",
    "is" : "jest",
    "is not" : "nie jest",
    "matches" : "pasuje",
    "does not match" : "nie pasuje",
    "Example: {placeholder}" : "Przykład: {placeholder}",
    "File size (upload)" : "Rozmiar pliku (wczytywanego)",
    "less" : "mniejszy",
    "less or equals" : "mniejszy lub równy",
    "greater or equals" : "większy lub równy",
    "greater" : "większy",
    "File system tag" : "Etykieta systemu plików",
    "is tagged with" : "jest oznaczony",
    "is not tagged with" : "Nie jest oznaczony",
    "Select tag…" : "Wybierz etykietę...",
    "Request remote address" : "Uzyskaj zdalny adres",
    "matches IPv4" : "pasuje IPv4",
    "does not match IPv4" : "nie pasuje IPv4",
    "matches IPv6" : "pasuje IPv6",
    "does not match IPv6" : "nie pasuje IPv6",
    "Request time" : "Czas odpowiedzi",
    "between" : "pomiędzy",
    "not between" : "nie pomiędzy",
    "Start" : "Start",
    "End" : "Koniec",
    "Select timezone…" : "Wybierz strefę czasową...",
    "Request URL" : "Żądanie URL",
    "Predefined URLs" : "Przedefiniowanie URLs",
    "Files WebDAV" : "Pliki WebDAV",
    "Request user agent" : "Żądanie agenta użytkownika",
    "Sync clients" : "Klienci synchronizacji",
    "Android client" : "Klient Android",
    "iOS client" : "Klient iOS",
    "Desktop client" : "Klient na komputer",
    "User group membership" : "Członkostwo grupy użytkownika",
    "is member of" : "jest członkiem w",
    "is not member of" : "nie jest członkiem w",
    "The given operator is invalid" : "Dana operacja jest nieprawidłowa",
    "The given regular expression is invalid" : "Podane wyrażenie regularne jest błędne",
    "The given file size is invalid" : "Podany rozmiar pliku jest nieprawidłowy",
    "The given tag id is invalid" : "Podane id etykiety jest nieprawidłowe",
    "The given IP range is invalid" : "Podany zakres adresów IP jest nieprawidłowy",
    "The given IP range is not valid for IPv4" : "Podany zakres adresów IP jest nieprawidłowy dla IPv4",
    "The given IP range is not valid for IPv6" : "Podany zakres adresów IP jest nieprawidłowy dla IPv6",
    "The given time span is invalid" : "Podany przedział czasowy jest nieprawidłowy",
    "The given start time is invalid" : "Podany czas rozpoczęcia jest nieprawidłowy",
    "The given end time is invalid" : "Podany czas zakończenia jest nieprawidłowy",
    "The given group does not exist" : "Podana grupa nie istnieje",
    "Check %s is invalid or does not exist" : "Sprawdź, czy %s jest nieprawidłowa lub nie istnieje",
    "Operation #%s does not exist" : "Operacja do wykonania #%s nie istnieje",
    "Operation %s does not exist" : "Operacja do wykonania %s nie istnieje",
    "Operation %s is invalid" : "Operacja %s jest nieprawidłowa",
    "Check %s does not exist" : "Sprawdź, czy %s nie istnieje",
    "Check %s is invalid" : "Sprawdź, czy %s jest nieprawidłowy",
    "Check #%s does not exist" : "Sprawdź, czy #%s nie istnieje",
    "Workflow" : "Wpływ na pracę",
    "Files workflow engine" : "Silnik przepływu pracy nad plikami",
    "Open documentation" : "Otwórz dokumentację",
    "Add rule group" : "Dodaj grupę reguł",
    "Short rule description" : "Krótki opis reguły",
    "Add rule" : "Dodaj regułę",
    "Reset" : "Zresetuj",
    "Save" : "Zapisz",
    "Saving…" : "Zapisywanie...",
    "Loading…" : "Wczytywanie...",
    "Successfully saved" : "Zapis się powiódł",
    "File mime type" : "Typ MIME pliku"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
